@@ -1,5 +1,6 @@
 package Module::Build::Scintilla::MSW;
 
+use 5.006;
 use strict;
 use warnings;
 use Module::Build::Scintilla;
@@ -87,6 +88,9 @@ sub stc_link_scintilla_objects {
 sub stc_build_xs {
 	my ($self) = @_;
 
+	# Do not build XS if it is up to date
+	return if $self->up_to_date( 'Scintilla.c', 'Scintilla.obj' );
+
 	my $dist_version = $self->dist_version;
 
 	my @cmd = (
